Module blaxel.core.client.models.volume_attachment
==================================================

Classes
-------

`VolumeAttachment(mount_path: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, read_only: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>)`
:   Volume attachment configuration for sandbox
    
    Attributes:
        mount_path (Union[Unset, str]): Mount path in the container
        name (Union[Unset, str]): Name of the volume to attach
        read_only (Union[Unset, bool]): Whether the volume is mounted as read-only
    
    Method generated by attrs for class VolumeAttachment.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `mount_path: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    `read_only: blaxel.core.client.types.Unset | bool`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :